-- NMAS Schema Definitions
-- NetIQ Corporation, 
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA
--
-- Version=NMAS 8.8.8.0 2013 06 17
-- Copyright=(c) Copyright 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
--
-- Object ID (OID) is registered with Internal Schema Registration
-- as of 15 Jan 1997.
--
-- OIDs Defined as Follows:
--   joint-iso-ccitt(2) country(16) us(840) organization(1)
--   Novell(113719) applications(1) SAS(39) NMAS(42)
--                 SASFAttributeType(1) version# attr#         
--                 SASFObjectClass(2)   version# class#

SASFSchemaExtentions DEFINITIONS ::=
BEGIN


-- --------------------------------------
-- SAS Login Policy Attributes
-- --------------------------------------


-- This attribute contains the login sequences defined for the tree
-- The format of this attribute is login sequence name, followed by
-- the sequence grade name, followed by the name of each method in
-- the sequence.  The ";" and "|" are used to delimit the strings.
    "SAS:Login Sequence" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 2}
    }

    "SAS:Login Policy Update" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 8}
    }

    "sasNMASProductOptions" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 38}
    }

-- The NMAS Audit flags:
-- 0x0 = Audit disabled, NMAS will not attempt to connect to auditing system
-- 0x1 = Audit enabled, requested action will not fail if NMAS is unabled to connect to auditing system
-- 0x2 = Audit required, requested action will fail if NMAS is unabled to connect to auditing system (not implemented in NMAS 3.1.1)
-- 0x4 = Sign events (not implemented in NMAS 3.1.1)
-- 0x8 = Use external certificate and private key (not implemented in NMAS 3.1.1)
    "sasAuditConfiguration" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 74}
    }

-- --------------------------------------
-- SAS Login Policy Attributes (BMEE 3.5)
-- --------------------------------------
    "SAS:NDS Password Window" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 14}
    }

    "SAS:Policy Credentials" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 15}
    }

    "SAS:Policy Methods" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_PATH,
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 16}
    }

    "SAS:Policy Object Version" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 17}
    }

    "SAS:Policy Service Subtypes" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_PATH,
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 18}
    }

    "SAS:Policy Services" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_PATH,
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 19}
    }

    "SAS:Policy Users" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_PATH,
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 20}
    }

    "SAS:Allow NDS Password Window" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 21}
    }

-- ------------------------
-- Login Method Attributes 
-- ------------------------
    "SAS:Method Identifier" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 9}
    }

    "SAS:Method Vendor" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 10}
    }

    "SAS:Advisory Method Grade" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 11}
    }

    "SAS:Vendor Support" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 12}
    }

   "sasCertificateSearchContainers" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        Flags       {DS_PUBLIC_READ},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 13}
    }

    "sasNMASMethodConfigData" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        Flags       {DS_SINGLE_VALUED_ATTR, DS_PUBLIC_READ},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 70}
    }

    "SAS:Login Client Method NetWare" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 22}
    }

    "SAS:Login Server Method NetWare" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 23}
    }
    
    "SAS:Login Client Method WINNT" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 24}
    }

    "SAS:Login Server Method WINNT" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 25}
    }

    "sasLoginClientMethodSolaris" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 26}
    }

    "sasLoginServerMethodSolaris" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 27}
    }

    "sasLoginClientMethodLinux" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 28}
    }

    "sasLoginServerMethodLinux" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 29}
    }

    "sasLoginClientMethodTru64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 30}
    }

    "sasLoginServerMethodTru64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 31}
    }

    "sasLoginClientMethodAIX" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 32}
    }

    "sasLoginServerMethodAIX" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 33}
    }

    "sasLoginClientMethodHPUX" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 34}
    }

    "sasLoginServerMethodHPUX" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 35}
    }

    "sasLoginClientMethods390" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1000}
    }

    "sasLoginServerMethods390" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1001}
    }

    "sasLoginClientMethodLinuxX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1002}
    }

    "sasLoginServerMethodLinuxX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1003}
    }

    "sasLoginClientMethodWinX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1004}
    }

    "sasLoginServerMethodWinX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1005}
    }

    "sasLoginClientMethodSolaris64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1006}
    }

    "sasLoginServerMethodSolaris64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1007}
    }

    "sasLoginClientMethodAIX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1008}
    }

    "sasLoginServerMethodAIX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1009}
    }

    "sasLoginServerMethodSolarisi386" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1011}
    }

    "sasLoginClientMethodSLinuxX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1017}
    }

    "sasLoginServerMethodSLinuxX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1018}
    }

    "sasLoginClientMethodSWinX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1019}
    }

    "sasLoginServerMethodSWinX64" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1020}
    }

    "sasLoginClientMethodSolarisi386" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1012}
    }

    "sasUnsignedMethodModules" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 78}
    }

    "sasServerModuleName" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 79}
    }

    "sasServerModuleEntryPointName" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 80}
    }

    "sasSASLMechanismName" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 81}
    }

    "sasSASLMechanismEntryPointName" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 82}
    }

    "sasClientModuleName" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 83}
    }

    "sasClientModuleEntryPointName" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 84}
    }

-- --------------------------------------
-- Attributes for the SAS:Security Object
-- --------------------------------------

-- Holds the distinguished name of the of the
-- Login Methods Container.
    "SAS:Login Method Container DN" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        Flags       {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 36}
    }

-- Holds the distinguished name of the of the Login Policy
    "SAS:Login Policy DN" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        Flags       {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 37}
    }

-- Holds the distinguished name of the of the
-- Post Login Methods Container
    "sasPostLoginMethodContainerDN" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        Flags       {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 63}
    }

-- --------------------------------------
-- Attributes for RADIUS
-- --------------------------------------
    "RADIUS:Active Connections" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 38}
    }

    "RADIUS:Aged Interval" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 39} 
    }

    "RADIUS:Attribute List" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 40} 
    }

    "RADIUS:Attribute Lists" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 41} 
    }

    "RADIUS:Client" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 42} 
    }

    "RADIUS:Common Name Resolution" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 43} 
    }

    "RADIUS:Concurrent Limit" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 44} 
    }

    "RADIUS:Connection History" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 45} 
    }

    "RADIUS:DAS Version" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 46} 
    }

    "RADIUS:Default Profile" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_CI_STRING,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 47} 
    }

    "RADIUS:Dial Access Group" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 48} 
    }

    "RADIUS:Enable Common Name Login" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_BOOLEAN,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 49} 
    }

    "RADIUS:Enable Dial Access" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_BOOLEAN,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 50} 
    }

    "RADIUS:Interim Accting Timeout" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 51} 
    }

    "RADIUS:Lookup Contexts" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 52} 
    }

    "RADIUS:Max DAS History Record" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 53} 
    }

    "RADIUS:Maximum History Record" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 54} 
    }

    "RADIUS:Password" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 55} 
    }

    "RADIUS:Password Policy" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_INTEGER,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 56} 
    }

    "RADIUS:Private Key" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 57} 
    }

    "RADIUS:Proxy Context" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_PATH,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 58} 
    }

    "RADIUS:Proxy Domain" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 59} 
    }

    "RADIUS:Proxy Target" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 60} 
    }

    "RADIUS:Public Key" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_OCTET_STRING,
        Flags       {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 61} 
    }

    "RADIUS:Service List" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_PATH,
        ASN1ObjID   {2 16 840 1 113719 1 39 42 1 0 62} 
    }

    "sasNDSPasswordWindow" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 64}
    }

    "sasPolicyMethods" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_PATH,
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 65}
    }

    "sasPolicyServices" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_PATH,
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 66}
    }

    "sasPolicyUsers" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_PATH,
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 67}
    }

    "sasAllowNDSPasswordWindow" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 68}
    }

-- ----------------------------------------
-- Attributes for ndsLoginProperties Class
-- ----------------------------------------
 
    "SAS:Login Secret" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_SERVER_READ, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 3}
    }

    "SAS:Login Secret Key" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_SERVER_READ, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 4}
    }

    "SAS:Encryption Type" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 5}
    }

    "SAS:Login Configuration" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_SERVER_READ, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 6}
    }

    "SAS:Login Configuration Key" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_SERVER_READ, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 7}
    }

    "sasDefaultLoginSequence" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 73}
    }

    "sasAuthorizedLoginSequences" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 64}
    }

    "sasAllowableSubjectNames" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CI_STRING,
        Flags        {DS_PUBLIC_READ, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 69}
    }

    "sasLoginFailureDelay" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 71}
    }

    "sasMethodVersion" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 72}
    }

-- Specifies what login attributes are to be updated on the user object during login.
-- Following are the possible values :
-- 0 : Do not update any login attributes. (Off)
-- 1 : Only update attributes that are required by intruder detection.
-- 2 : Update all login attributes except unused user password policy attributes.
-- 3 : Update all login attributes. (On)
    "sasUpdateLoginInfo" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1010}
    }

-- OATH OTP status. Enabled (TRUE), Disabled (FALSE)
    "sasOTPEnabled" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1011}
    }

-- OATH OTP counter value; per-user only
    "sasOTPCounter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_COUNTER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1012}
    }

-- OATH OTP re-synchronization look ahead window; system parameter
    "sasOTPLookAheadWindow" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1013}
    }

-- OATH OTP number of digits
    "sasOTPDigits" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1014}
    }

-- OATH OTP resync value; per-user only. set by administrator, used for out-of-box way to reset the counter.
    "sasOTPReSync" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1015}
    }

-- Specifies after what interval the login attributes - last login time and login time - are to be updated on the user object during login.
-- Following are the possible values :
-- 0 : Update Immediately
-- 1-1440 : Update after 1,2,3....1440 minutes(upto 1 Day)
    "sasUpdateLoginTimeInterval" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SERVER_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 1 0 1016}
    }

-- -------------------
-- Class Definitions
-- -------------------

-- ---------------------------------------
-- This class is also defined by BMEE 3.5
-- ---------------------------------------
    "SAS:Login Method Container" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"SAS:Security", "Country", "Locality", "Organizational Unit", "Organization"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 1}
    }
 
-- Class numbers 2, 3, 5 and 6 defined by BMEE3.5

-- ---------------------------------------
-- This class is also defined by BMEE 3.5
-- ---------------------------------------
    "SAS:Login Policy" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"SAS:Security"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description",
                      "Private Key", 
                      "Public Key",
                      "SAS:Allow NDS Password Window",
                      "SAS:Policy Credentials",
                      "SAS:Policy Methods",
                      "SAS:Policy Object Version",
                      "SAS:Policy Service Subtypes",
                      "SAS:Policy Services",
                      "SAS:Policy Users"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 4}
    }

-- Class numbers 2, 3, 5 and 6 defined by BMEE3.5

    "SAS:NMAS Base Login Method" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_CONTAINER_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"SAS:Login Method Container"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description",
                      "SAS:Login Secret",
                      "SAS:Login Secret Key",
                      "SAS:Encryption Type",
                      "SAS:Login Configuration",
                      "SAS:Login Configuration Key",
                      "SAS:Method Identifier",
                      "SAS:Method Vendor",
                      "SAS:Vendor Support",
                      "SAS:Advisory Method Grade",
                      "SAS:Login Client Method NetWare",
                      "SAS:Login Server Method NetWare",
                      "SAS:Login Client Method WINNT",
                      "SAS:Login Server Method WINNT"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 7}
    }

    "SAS:NMAS Login Method" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
        SubClassOf   {"SAS:NMAS Base Login Method"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 8}
    }

    "RADIUS:Dial Access System" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"Country","Locality", "Organizational Unit","Organization"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Public Key",
                      "Private Key",
                      "RADIUS:Aged Interval",
                      "RADIUS:Client",
                      "RADIUS:Common Name Resolution",
                      "RADIUS:Concurrent Limit",
                      "RADIUS:DAS Version",
                      "RADIUS:Enable Common Name Login",
                      "RADIUS:Enable Dial Access",
                      "RADIUS:Interim Accting Timeout",
                      "RADIUS:Lookup Contexts",
                      "RADIUS:Max DAS History Record",
                      "RADIUS:Maximum History Record",
                      "RADIUS:Password Policy",
                      "RADIUS:Private Key",
                      "RADIUS:Proxy Context",
                      "RADIUS:Proxy Domain",
                      "RADIUS:Proxy Target",
                      "RADIUS:Public Key"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 9}
    }

    "RADIUS:Profile" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"Country","Locality","Organizational Unit","Organization"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"RADIUS:Attribute List"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 10}
    }


    "sasPostLoginMethodContainer" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"SAS:Security"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 11}
    }
 
    "sasPostLoginMethod" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"sasPostLoginMethodContainer"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description",
                      "SAS:Login Secret",
                      "SAS:Login Secret Key",
                      "SAS:Encryption Type",
                      "SAS:Login Configuration",
                      "SAS:Login Configuration Key",
                      "SAS:Method Identifier",
                      "SAS:Method Vendor",
                      "SAS:Vendor Support",
                      "SAS:Advisory Method Grade",
                      "SAS:Login Client Method NetWare",
                      "SAS:Login Server Method NetWare",
                      "SAS:Login Client Method WINNT",
                      "SAS:Login Server Method WINNT"},
        ASN1ObjID    {2 16 840 1 113719 1 39 42 2 0 12}
    }

-- --------------------------------
-- Modification of Existing Classes
-- --------------------------------

    "SAS:Login Policy" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        MayContain     {"SAS:Login Sequence",
                        "SAS:Login Policy Update",
                        "sasNMASProductOptions",
                        "sasPolicyMethods",
                        "sasPolicyServices",
                        "sasPolicyUsers",
                        "sasAllowNDSPasswordWindow",
                        "sasLoginFailureDelay",
                        "sasDefaultLoginSequence",
                        "sasAuthorizedLoginSequences",
                        "sasAuditConfiguration",
                        "sasUpdateLoginInfo",
                        "sasOTPEnabled",
                        "sasOTPLookAheadWindow",
                        "sasOTPDigits"
                       }
    }

    "SAS:NMAS Base Login Method" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        MayContain     {"sasCertificateSearchContainers",
                        "sasNMASMethodConfigData",
                        "sasMethodVersion",
                        "SAS:Login Policy Update",
                        "sasUnsignedMethodModules",
                        "sasServerModuleName",
                        "sasServerModuleEntryPointName",
                        "sasSASLMechanismName",
                        "sasSASLMechanismEntryPointName",
                        "sasClientModuleName",
                        "sasClientModuleEntryPointName",
                        "sasLoginClientMethodSolaris",
                        "sasLoginServerMethodSolaris",
                        "sasLoginClientMethodLinux",
                        "sasLoginServerMethodLinux",
                        "sasLoginClientMethodTru64",
                        "sasLoginServerMethodTru64",
                        "sasLoginClientMethodAIX",
                        "sasLoginServerMethodAIX",
                        "sasLoginClientMethodHPUX",
                        "sasLoginServerMethodHPUX",
                        "sasLoginClientMethods390",
                        "sasLoginServerMethods390",
                        "sasLoginClientMethodLinuxX64",
                        "sasLoginServerMethodLinuxX64",
                        "sasLoginClientMethodWinX64",
                        "sasLoginServerMethodWinX64",
                        "sasLoginClientMethodSLinuxX64",
                        "sasLoginServerMethodSLinuxX64",
                        "sasLoginClientMethodSWinX64",
                        "sasLoginServerMethodSWinX64",
                        "sasLoginClientMethodSolaris64",
                        "sasLoginServerMethodSolaris64",
                        "sasLoginClientMethodSolarisi386",
                        "sasLoginServerMethodSolarisi386",
                        "sasLoginClientMethodAIX64",
                        "sasLoginServerMethodAIX64"}
    }

    "sasPostLoginMethod" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        MayContain     {"sasMethodVersion",
                        "SAS:Login Policy Update",
                        "sasUnsignedMethodModules",
                        "sasServerModuleName",
                        "sasServerModuleEntryPointName",
                        "sasSASLMechanismName",
                        "sasSASLMechanismEntryPointName",
                        "sasClientModuleName",
                        "sasClientModuleEntryPointName",
                        "sasLoginClientMethodSolaris",
                        "sasLoginServerMethodSolaris",
                        "sasLoginClientMethodLinux",
                        "sasLoginServerMethodLinux",
                        "sasLoginClientMethodTru64",
                        "sasLoginServerMethodTru64",
                        "sasLoginClientMethodAIX",
                        "sasLoginServerMethodAIX",
                        "sasLoginClientMethodHPUX",
                        "sasLoginServerMethodHPUX",
                        "sasLoginClientMethods390",
                        "sasLoginServerMethods390",
                        "sasLoginClientMethodLinuxX64",
                        "sasLoginServerMethodLinuxX64",
                        "sasLoginClientMethodWinX64",
                        "sasLoginServerMethodWinX64",
                        "sasLoginClientMethodSLinuxX64",
                        "sasLoginServerMethodSLinuxX64",
                        "sasLoginClientMethodSWinX64",
                        "sasLoginServerMethodSWinX64",
                        "sasLoginClientMethodSolaris64",
                        "sasLoginServerMethodSolaris64",
                        "sasLoginClientMethodSolarisi386",
                        "sasLoginServerMethodSolarisi386",
                        "sasLoginClientMethodAIX64",
                        "sasLoginServerMethodAIX64"}
    }

   "SAS:Security" OBJECT-CLASS ::=
   {
        Operation       MODIFY,
        MayContain      {"SAS:Login Policy DN",
                         "SAS:Login Method Container DN",
                         "sasPostLoginMethodContainerDN"}
   }

    "Organization" OBJECT-CLASS ::=
    {
        Operation       MODIFY,
        MayContain      {"RADIUS:Attribute Lists",
                         "RADIUS:Default Profile",
                         "RADIUS:Dial Access Group",
                         "RADIUS:Enable Dial Access",
                         "RADIUS:Service List"}
    }

    "Organizational Unit" OBJECT-CLASS ::=
    {
        Operation       MODIFY,
        MayContain      {"RADIUS:Attribute Lists",
                         "RADIUS:Default Profile",
                         "RADIUS:Dial Access Group",
                         "RADIUS:Enable Dial Access",
                         "RADIUS:Service List"}
    }

    "ndsLoginProperties" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        MayContain   {"SAS:NDS Password Window",
                      "SAS:Login Secret",
                      "SAS:Login Secret Key",
                      "SAS:Encryption Type",
                      "SAS:Login Configuration",
                      "SAS:Login Configuration Key",
                      "sasLoginFailureDelay",
                      "sasDefaultLoginSequence",
                      "sasAuthorizedLoginSequences",
                      "sasAllowableSubjectNames",
                      "sasUpdateLoginInfo",
                      "sasOTPEnabled",
                      "sasOTPCounter",
                      "sasOTPDigits",
                      "sasOTPReSync"}
    }
    
    "ndsContainerLoginProperties" OBJECT-CLASS ::=
    {
        Operation   MODIFY,
        MayContain  {
                      "sasLoginFailureDelay",
                      "sasDefaultLoginSequence",
                      "sasAuthorizedLoginSequences",
                      "sasUpdateLoginInfo",
                      "sasOTPEnabled",
                      "sasOTPDigits"
                    }
    }

    "User" OBJECT-CLASS ::=
    {
        Operation       MODIFY,
        MayContain      {"RADIUS:Active Connections",
                         "RADIUS:Attribute Lists",
                         "RADIUS:Concurrent Limit",
                         "RADIUS:Connection History",
                         "RADIUS:Default Profile",
                         "RADIUS:Dial Access Group",
                         "RADIUS:Enable Dial Access",
                         "RADIUS:Password",
                         "RADIUS:Service List"}
    }

    "RADIUS:Dial Access System" OBJECT-CLASS ::=
    {
        Operation       MODIFY,
        MayContain      {"SAS:Login Configuration",
                         "SAS:Login Configuration Key"}
    }
	
    "SAS:Login Policy" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        MayContain     {"sasUpdateLoginTimeInterval"}
    }


    "ndsLoginProperties" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        MayContain     {"sasUpdateLoginTimeInterval"}
    }               


    "ndsContainerLoginProperties" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        MayContain     {"sasUpdateLoginTimeInterval"}
    }

END


