-- NetIQ SMTP and Template Notification Schema Definitions
-- NetIQ Corporation, 
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA
--
-- Version= 1.0 2003 02 20
-- Copyright=(c) Copyright 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
-- Engineer= Will Peterson


NOTFSchemaExtentions DEFINITIONS ::=
BEGIN

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Notification Template Collection Attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- SMTP Email Host Name or IPAddress
	"notfSMTPEmailHost" ATTRIBUTE ::=
    {
      Operation	      ADD,
      SyntaxID	      SYN_CI_STRING,
      Flags           {DS_SINGLE_VALUED_ATTR},
      ASN1ObjID	      {2 16 840 1 113719 1 7 4 1}
    }

-- SMTP Email "From" Display String
	"notfSMTPEmailFrom" ATTRIBUTE ::=
    {
      Operation	      ADD,
      SyntaxID	      SYN_CI_STRING,
      Flags           {DS_SINGLE_VALUED_ATTR},
      ASN1ObjID	      {2 16 840 1 113719 1 7 4 2}
    }

-- SMTP Email UserName
	"notfSMTPEmailUserName" ATTRIBUTE ::=
    {
      Operation	      ADD,
      SyntaxID	      SYN_CI_STRING,
      Flags           {DS_SINGLE_VALUED_ATTR},
      ASN1ObjID	      {2 16 840 1 113719 1 7 4 3}
    }

-- SMTP Configure SSL
        "notfSMTPUseTLS" ATTRIBUTE ::=
    {
      Operation       ADD,
      SyntaxID        SYN_BOOLEAN,
      Flags           {DS_SINGLE_VALUED_ATTR},
      ASN1ObjID       {2 16 840 1 113719 1 7 4 4}
    }

-- SMTP Configure TimeOut Value
        "notfSMTPTimeout" ATTRIBUTE ::=
    {
      Operation       ADD,
      SyntaxID        SYN_INTEGER,
      Flags           {DS_SINGLE_VALUED_ATTR},
      ASN1ObjID       {2 16 840 1 113719 1 7 4 5}
    }

-- SecretStore attribute for user and service objects.
	"SAS:SecretStore" ATTRIBUTE ::=
    {
      Operation	      ADD,
      SyntaxID	      SYN_BOOLEAN,
      Flags           {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
      ASN1ObjID	      {2 16 840 1 113719 1 39 4 1 3}
    }

-- SecretStore key attribute for user and service objects.
	"SAS:SecretStoreKey" ATTRIBUTE ::=
    {
      Operation       ADD,
      SyntaxID        SYN_OCTET_STRING,
      Flags           {DS_HIDDEN_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
      ASN1ObjID	      {2 16 840 1 113719 1 39 4 1 4}
    }

-- SecretStore data attribute for user and service objects.
	"SAS:SecretStoreData" ATTRIBUTE ::=
    {
      Operation       ADD,
      SyntaxID        SYN_OCTET_STRING,
      Flags           {DS_HIDDEN_ATTR, DS_SYNC_IMMEDIATE},
      ASN1ObjID       {2 16 840 1 113719 1 39 4 1 5}
    }

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Merge Template Attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- XML Merge Template Data
	"notfMergeTemplateData" ATTRIBUTE ::=
    {
      Operation	      ADD,
      SyntaxID	      SYN_CE_STRING,
      Flags           {DS_SINGLE_VALUED_ATTR},
      ASN1ObjID	      {2 16 840 1 113719 1 7 4 5}
    }

-- Merge Template Subject
	"notfMergeTemplateSubject" ATTRIBUTE ::=
    {
      Operation	      ADD,
      SyntaxID	      SYN_CE_STRING,
      Flags           {DS_SINGLE_VALUED_ATTR},
      ASN1ObjID	      {2 16 840 1 113719 1 7 4 6}
    }

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Notification Container Class Definitions
-- -- -- -- -- -- -- -- -- -- -- -- --

-- The container that contains all Merge Template objects
    "notfTemplateCollection" OBJECT-CLASS ::=
    {
      Operation       ADD,
      Flags           {DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
      SubClassOf      {"TOP"},
      ContainedBy     {"SAS:Security"},
      NamedBy         {"CN"},
      MustContain     {"CN"},
      MayContain      {"notfSMTPEmailHost",
                       "notfSMTPEmailFrom",
                       "notfSMTPEmailUserName",
                       "notfSMTPUseTLS",
                       "notfSMTPTimeout",
                       "SAS:SecretStore",
                       "SAS:SecretStoreKey",
                       "SAS:SecretStoreData"},
      ASN1ObjID       {2 16 840 1 113719 1 7 6 1}
    }

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Merge Template Class Definitions
-- -- -- -- -- -- -- -- -- -- -- -- --
 
-- Merge Template object
    "notfMergeTemplate" OBJECT-CLASS ::=
    {
      Operation       ADD,
      Flags           {DS_EFFECTIVE_CLASS},
      SubClassOf      {"TOP"},
      ContainedBy     {"notfTemplateCollection"},
      NamedBy         {"CN"},
      MustContain     {"CN"},
      MayContain      {"notfMergeTemplateData",
                       "notfMergeTemplateSubject"},
      ASN1ObjID       {2 16 840 1 113719 1 7 6 2}
    }

END
