-- NetIQ Secure Password Manager Schema Definitions
-- NetIQ Corporation, 
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA
--
-- Version=NMAS 8.8.8 2013 06 17
-- Copyright=(c) Copyright 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
--
-- Object ID (OID) is registered with Internal Schema Registration
-- as of 15 Jan 1997.
--
-- OIDs Defined as Follows:
--   joint-iso-ccitt(2) country(16) us(840) organization(1)
--   Novell(113719) applications(1) SAS(39) NSPM(43)
--                                          NSPMAttributeType(4) attr#         
--                                          NSPMObjectClass(6)   class#

NSPMSchemaExtentions DEFINITIONS ::=
BEGIN

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Password User Attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- User specific secret key that is wrapped with Security Domain Key.
    "nspmPasswordKey" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_HIDDEN_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 1}
    }

-- The current user password.  It is a null terminated unicode string encrypted with
-- the user specific secret key that is stored in the nspmPasswordKey attribute.
    "nspmPassword" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_HIDDEN_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 2}
    }

-- The user distribution password.  It may or may not be the same value as the
-- user's current password.  It is a null terminated unicode string encrypted with
-- the user specific secret key that is stored in the nspmPasswordKey attribute.
    "nspmDistributionPassword" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_HIDDEN_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 3}
    }

-- The user password history.  Each password is a null terminated unicode string encrypted
-- with the user specific secret key that is stored in the nspmPasswordKey attribute.
    "nspmPasswordHistory" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_HIDDEN_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 4}
    }

-- This attribute indicates the number of times that the administrator set
-- user's the login credentials.
-- This is to support the non-repudiation feature of Single Sign-on.
    "nspmAdministratorChangeCount" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_COUNTER,
        Flags        {DS_HIDDEN_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 5}
    }

-- Attribute on the login properties object (e.g., user object)
-- that specifies the effective Password Policy for the object
    "nspmPasswordPolicyDN" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        Flags       {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 6}
    }

-- The previous user distribution password.  It is a null terminated unicode string
-- encrypted with the user specific secret key that is stored in the nspmPasswordKey attribute.
    "nspmPreviousDistributionPassword" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OCTET_STRING,
        Flags        {DS_HIDDEN_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 7}
    }

-- When this attribute is set to TRUE the user's password will not expire.
-- If this attribute is set to FALSE or does not exist then the password 
-- expiration configuration as defined by the password policy associated
-- with the user will be enforced.
    "nspmDoNotExpirePassword" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 8}
    }

-- This attribute specifies the last time the entry's password was changed.
-- As defined in the Password Policy for LDAP Directories IETF Draft October 24, 2004
    "pwdChangedTime" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_TIME,
        Flags        {DS_READ_ONLY_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {1 3 6 1 4 1 42 2 27 8 1 16}
    }

-- This attribute specifies the time that the user's account was locked.
-- As defined in the Password Policy for LDAP Directories IETF Draft October 24, 2004
    "pwdAccountLockedTime" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_TIME,
        Flags        {DS_READ_ONLY_ATTR, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {1 3 6 1 4 1 42 2 27 8 1 17}
    }

-- This attribute holds the timestamps of the consecutive login failures.
-- As defined in the Password Policy for LDAP Directories IETF Draft October 24, 2004
    "pwdFailureTime" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_TIME,
        Flags        {DS_READ_ONLY_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {1 3 6 1 4 1 42 2 27 8 1 19}
    }

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Password Policy Configuration Attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- The NSPM options flags:
-- 0x01 = On set password request the NDS password hash will be removed by SPM
-- 0x02 = On set password request the NDS password hash will not be set by SPM
-- 0x04 = On set password request the Simple password will not be set by SPM
-- 0x08 = Allow Simple password to be set
-- 0x10 = Allow password retrieval by self
-- 0x20 = Allow password retrieval by admin
-- 0x40 = Allow password retrieval by password agents
-- 0x100 = Password enabled
-- 0x200 = Advanced password policy enabled
    "nspmConfigurationOptions" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 100}
    }

-- Administrator defined message to be displayed when a user is prompted to change his password
    "nspmChangePasswordMessage" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CE_STRING,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 102}
    }

-- The maximum number of passwords stored user password history.  If the
-- number of passwords in the password history exceed the value of this
-- attribute and if the password is not expired then the user can not
-- change the password.  Note that this attribute is ignored if the
-- pwdInHistory attribute exists.
    "nspmPasswordHistoryLimit" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 103}
    }

-- The maximum number of passwords stored user password history.  If the
-- number of passwords in the password history exceed the value of this
-- attribute and if the password is not expired then the user can not
-- change the password.  Note that this attribute is ignored if the
-- pwdInHistory attribute exists.
    "nspmPasswordHistoryLimit" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 103}
    }

-- The minimum time in seconds that passwords are stored user password history.
-- Note that this attribute is ignored if the  pwdInHistory attribute exists.
    "nspmPasswordHistoryExpiration" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 104}
    }

-- This attribute specifies the maximum number of used passwords stored
-- in the nspmPasswordHistory attribute.  As defined in the Password
-- Policy for LDAP Directories IETF Draft October 24, 2004
-- Note that if this attribute exists then the values of the
-- nspmPasswordHistoryLimit, the nspmPasswordHistoryExpiration, and the
-- Password Unique Required are ignored
    "pwdInHistory" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {1 3 6 1 4 1 42 2 27 8 1 4}
    }

-- The minimum time in seconds that the user is allowed to change his password again.
    "nspmMinPasswordLifetime" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 105}
    }

-- When this attribute is set to TRUE the user's password is not expired when the
-- administrator sets the password.  If this attribute is set to FALSE or does not
-- exist then the password expiration configuration as defined by the password policy
-- is enforced.
    "nspmAdminsDoNotExpirePassword" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 106}
    }

-- Access control list that specifies which identities can read passwords
-- of objects associated with the password policy
    "nspmPasswordACL" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_OBJECT_ACL,
        Flags        {DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 107}
    }

-- Algorithm used for computing PBKDF2 hash of user's password
    "nspmPBKDF2HashAlgorithm" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CE_STRING,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 108}
    }

-- Iteration count for computing PBKDF2 hash of user's password
    "nspmPBKDF2IterationCount" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 109}
    }

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Password Syntax Attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- Maximum number of characters
    "nspmMaximumLength" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 200}
    }

-- Minimum number of upper case characters required
    "nspmMinUpperCaseCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 201}
    }

-- Maximum number of upper case characters allowed
    "nspmMaxUpperCaseCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 202}
    }

-- Minimum number of lower case characters required
    "nspmMinLowerCaseCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 203}
    }

-- Maximum number of lower case characters allowed
    "nspmMaxLowerCaseCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 204}
    }

-- Numeric characters allowed flag.  Note that if this attribute
-- does not exist then numeric characters are allowed, if the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.

    "nspmNumericCharactersAllowed" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 205}
    }

-- Indicates if numeric characters are disallowed as the first character of a password.
-- Numeric characters are allowed if this attribute is missing, if the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmNumericAsFirstCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 206}
    }

-- Indicates if numeric characters are disallowed as the last character of a password.
-- Numeric characters are allowed if this attribute is missing, if the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmNumericAsLastCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 207}
    }

-- Minimum number of numeric characters required
    "nspmMinNumericCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 208}
    }

-- Maximum number of numeric characters allowed
    "nspmMaxNumericCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 209}
    }

-- Special characters allowed flag.  Note that if this attribute
-- does not exist then special characters are allowed, if the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmSpecialCharactersAllowed" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 210}
    }

-- Indicates if special characters are disallowed as the first character of a password.
-- Special characters are allowed if this attribute is missing, if the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmSpecialAsFirstCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 211}
    }

-- Indicates if special characters are disallowed as the last character of a password.
-- Special characters are allowed if this attribute is missing, if the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmSpecialAsLastCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 212}
    }

-- Minimum number of special characters required
    "nspmMinSpecialCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 213}
    }

-- Maximum number of special characters allowed
    "nspmMaxSpecialCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 214}
    }

-- Maximum number of times a character can appear in a password
    "nspmMaxRepeatedCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 215}
    }

-- Maximum number of times a character can appear consecutivly in a password
    "nspmMaxConsecutiveCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 216}
    }

-- Mimimum number of different characters must be in a password
    "nspmMinUniqueCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 217}
    }

-- Attribute values not allowed as a password or a portion of a password
    "nspmDisallowedAttributeValues" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CE_STRING,
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 218}
    }

-- Strings that are not allowed as a password or a portion of a password
    "nspmExcludeList" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 219}
    }

-- Case Sensitive comparison flag
    "nspmCaseSensitive" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 220}
    }

-- Used to determine which password policy takes precedence when
-- more than one password policy is associated with a user
    "nspmPolicyPrecedence" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 221}
    }

-- Extended characters allowed flag.  Note that if this attribute
-- does not exist then extended characters are allowed, if the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmExtendedCharactersAllowed" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 222}
    }

-- Indicates if extended characters are disallowed as the first character of a password.
-- Extended characters are allowed if this attribute is missing, provided the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmExtendedAsFirstCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 223}
    }

-- Indicates if extended characters are disallowed as the last character of a password.
-- Extended characters are allowed if this attribute is missing, provided the attribute
-- nspmNonAlphaCharactersAllowed is present and set to true.
    "nspmExtendedAsLastCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 224}
    }

-- Minimum number of extended characters required
    "nspmMinExtendedCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 225}
    }

-- Maximum number of extended characters allowed
    "nspmMaxExtendedCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 226}
    }

-- Indicates if uppercase characters are disallowed as the first character of a password.
-- Uppercase characters are allowed if this attribute is missing.
    "nspmUpperAsFirstCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 227}
    }

-- Indicates if uppercase characters are disallowed as the last character of a password.
-- Uppercase characters are allowed if this attribute is missing.
    "nspmUpperAsLastCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 228}
    }

-- Indicates if lowercase characters are disallowed as the first character of a password.
-- Lowercase characters are allowed if this attribute is missing.
    "nspmLowerAsFirstCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 229}
    }

-- Indicates if lowercase characters are disallowed as the last character of a password.
-- Lowercase characters are allowed if this attribute is missing.
    "nspmLowerAsLastCharacter" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 230}
    }

-- XML document that can be used to specify password syntax complexity rules
-- such as require three characters from four types of character
-- (uppercase, lowercase, numeric, and special)
    "nspmComplexityRules" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 231}
    }

-- Indicates if AD 2K8 Syntax is chosen and not MS complexity 
-- This is introduced in NMAS 3.3.4 
    "nspmAD2K8Syntax" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 233}
    }

-- Indicates the maximum number of violations allowed in AD 2K8 complexity policy
-- Introduced as part of AD2K8 implementation in NMAS 3.3.4
    "nspmAD2K8maxViolation" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 234}
    }

-- Indicates the number of characters which should be different from old password
-- Introduced in NMAS 3.3.4
    "nspmXCharLimit" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 235}
    }

-- Indicates the number of passwords from history to be checked for nspmXCharLimit 
-- Introduced in NMAS 3.3.4
    "nspmXCharHistoryLimit" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 236}
    }

-- Indicates if unicode characters are allowed. Currently not used in code
-- This is introduced in NMAS 3.3.4
    "nspmUnicodeAllowed" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 237}
    }

-- Indicates if non-alpha character are allowed in the password
-- This is introduced in NMAS 3.3.4
    "nspmNonAlphaCharactersAllowed" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 238}
    }

-- Indicates the minimum number of non-alpha characters required in password
-- Introduced in NMAS 3.3.4
    "nspmMinNonAlphaCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 239}
    }

-- Indicates the maximum number of non-alpha characters allowed in password
-- Introduced in NMAS 3.3.4
    "nspmMaxNonAlphaCharacters" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 240}
    }

-- Indicates the number of passwords to be considered in the history to 
-- provide the failed grace logins with out lockout (Refer bug 751928)
-- Schema change is being introduced as part to NMAS 3.3.4 and implementation
-- will be taken up in the subsequent patch
    "nspmGraceLoginHistoryLimit" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_INTEGER,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 241}
    }


-- -- -- -- -- -- -- -- -- -- -- -- --
-- Password Policy Agent Code Attributes
-- Executable code is stored for each supported OS platform
-- that will enforce the password policy.
-- -- -- -- -- -- -- -- -- -- -- -- --

-- Attribute on the Security Container that specifies the
-- container that contains all Password Policy Agent objects
    "nspmPolicyAgentContainerDN" ATTRIBUTE ::=
    {
        Operation   ADD,
        SyntaxID    SYN_DIST_NAME,
        Flags       {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 300}
    }

-- Password Policy Agent NetWare code
    "nspmPolicyAgentNetWare" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 301}
    }

-- Password Policy Agent Windows Server code
    "nspmPolicyAgentWINNT" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 302}
    }

-- Password Policy Agent Solaris code
    "nspmPolicyAgentSolaris" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 303}
    }

-- Password Policy Agent Linux code
    "nspmPolicyAgentLinux" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 304}
    }

-- Password Policy Agent AIX code
    "nspmPolicyAgentAIX" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 305}
    }

-- Password Policy Agent HPUX code
    "nspmPolicyAgentHPUX" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_STREAM,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 4 306}
    }


-- -------------------
-- Class Definitions
-- -------------------

-- The container that contains all Password Policy Agent objects
    "nspmPasswordPolicyContainer" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"SAS:Security"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description"},
        ASN1ObjID    {2 16 840 1 113719 1 39 43 6 2}
    }

    "nspmPasswordPolicyContainer" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        ContainedBy  {"Country", "Domain", "Locality", "Organization", "Organizational Unit"}
    }
 
-- Password Policy Agent object
    "nspmPolicyAgent" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"nspmPasswordPolicyContainer"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description",
                        "nspmPolicyAgentNetWare",
                        "nspmPolicyAgentWINNT",
                        "nspmPolicyAgentSolaris",
                        "nspmPolicyAgentLinux",
                        "nspmPolicyAgentAIX",
                        "nspmPolicyAgentHPUX"
                     },
        ASN1ObjID    {2 16 840 1 113719 1 39 43 6 3}
    }

    "nspmPasswordPolicy" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"nspmPasswordPolicyContainer", "Domain", "Locality", "Organization", "Organizational Unit"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description",
                        "nspmPolicyPrecedence",
                        "nspmConfigurationOptions",
                        "nspmChangePasswordMessage",
                        "Password Expiration Interval",
                        "Login Grace Limit",
                        "nspmMinPasswordLifetime",
                        "Password Unique Required",
                        "nspmPasswordHistoryLimit",
                        "nspmPasswordHistoryExpiration",
                        "Password Allow Change",
                        "Password Required",
                        "Password Minimum Length",
                        "nspmMaximumLength",
                        "nspmCaseSensitive",
                        "nspmMinUpperCaseCharacters",
                        "nspmMaxUpperCaseCharacters",
                        "nspmMinLowerCaseCharacters",
                        "nspmMaxLowerCaseCharacters",
                        "nspmNumericCharactersAllowed",
                        "nspmNumericAsFirstCharacter",
                        "nspmNumericAsLastCharacter",
                        "nspmMinNumericCharacters",
                        "nspmMaxNumericCharacters",
                        "nspmSpecialCharactersAllowed",
                        "nspmSpecialAsFirstCharacter",
                        "nspmSpecialAsLastCharacter",
                        "nspmMinSpecialCharacters",
                        "nspmMaxSpecialCharacters",
                        "nspmMaxRepeatedCharacters",
                        "nspmMaxConsecutiveCharacters",
                        "nspmMinUniqueCharacters",
                        "nspmDisallowedAttributeValues",
                        "nspmExcludeList",
                        "nspmExtendedCharactersAllowed"
                    },
        ASN1ObjID    {2 16 840 1 113719 1 39 43 6 1}
    }

    "nspmPasswordPolicy" OBJECT-CLASS ::=
    {
        Operation    MODIFY,
        ContainedBy  {"Country"}
    }

    "nspmPasswordPolicy" OBJECT-CLASS ::=
    {
        Operation   MODIFY,
        MayContain  {   
                        "nspmExtendedAsFirstCharacter",
                        "nspmExtendedAsLastCharacter",
                        "nspmMinExtendedCharacters",
                        "nspmMaxExtendedCharacters",
                        "nspmUpperAsFirstCharacter",
                        "nspmUpperAsLastCharacter",
                        "nspmLowerAsFirstCharacter",
                        "nspmLowerAsLastCharacter",
                        "nspmComplexityRules",
			"nspmAD2K8Syntax",
                        "nspmAD2K8maxViolation",
                        "nspmXCharLimit",
                        "nspmXCharHistoryLimit",
                        "nspmUnicodeAllowed",
                        "nspmNonAlphaCharactersAllowed",
                        "nspmMinNonAlphaCharacters",
                        "nspmMaxNonAlphaCharacters",
                        "pwdInHistory",
                        "nspmAdminsDoNotExpirePassword",
                        "nspmPasswordACL"
                    }
    }

    "nspmPasswordPolicy" OBJECT-CLASS ::=
    {
        Operation   MODIFY,
        MayContain  {
                        "nspmPBKDF2HashAlgorithm",
                        "nspmPBKDF2IterationCount"
                    }
    }

--
-- This auxillary class is applied to an object in the directory to allow the
-- object to have a nspmPassword assigned.  Currently the only classes that
-- may have the 'nspmPassword' attribute are those classes that inherit from
-- ndsLoginProperties.
--
"nspmPasswordAux" OBJECT-CLASS ::=
{
        Operation   ADD,
        Flags       {DS_AUXILIARY_CLASS},   
        MayContain  {   
                        "PUBLIC KEY",
                        "PRIVATE KEY",
                        "Login Grace Limit",
                        "Login Grace Remaining",
                        "Password Expiration Time",
                        "Password Required",
                        "nspmPasswordKey",
                        "nspmPassword",
                        "nspmDistributionPassword",
                        "nspmPreviousDistributionPassword",
                        "nspmPasswordHistory",
                        "nspmAdministratorChangeCount",
                        "nspmPasswordPolicyDN"
                    },
        ASN1ObjID    {2 16 840 1 113719 1 39 43 6 4}
}

"nspmPasswordAux" OBJECT-CLASS ::=
{
    Operation   MODIFY,
    MayContain  {   
                        "pwdChangedTime",
                        "pwdAccountLockedTime",
                        "pwdFailureTime",
                        "nspmDoNotExpirePassword"
                }
}

-- --------------------------------
-- Modification of Existing Classes
-- --------------------------------

    "ndsLoginProperties" OBJECT-CLASS ::=
    {
        Operation   MODIFY,
        MayContain  {   
                        "nspmPasswordKey",
                        "nspmPassword",
                        "pwdChangedTime",
                        "pwdAccountLockedTime",
                        "pwdFailureTime",
                        "nspmDoNotExpirePassword",
                        "nspmDistributionPassword",
                        "nspmPreviousDistributionPassword",
                        "nspmPasswordHistory",
                        "nspmAdministratorChangeCount",
                        "nspmPasswordPolicyDN"
                    }
    }

    "Group" OBJECT-CLASS ::=
    {
        Operation   MODIFY,
        MayContain  {
                        "nspmPasswordPolicyDN"
                    }
    }

    "ndsContainerLoginProperties" OBJECT-CLASS ::=
    {
        Operation   MODIFY,
        MayContain  {
                        "nspmPasswordPolicyDN"
                    }
    }

    "SAS:Login Policy" OBJECT-CLASS ::=
    {
        Operation   MODIFY,
        MayContain  {
                        "nspmPasswordPolicyDN"
                    }
    }

   "SAS:Security" OBJECT-CLASS ::=
   {
        Operation   MODIFY,
        MayContain  {
                        "nspmPolicyAgentContainerDN"
                    }
   }

END


